<?xml version="1.0"?> 
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

<xsl:include href="sprite-map.xsl"/>
<xsl:include href="typedef-convert.xsl"/>
<xsl:include href="typedef-convert.xsl"/>



<xsl:template name="level">
	<xsl:param name="id" select="0"/>
	
	<!-- Find the level file -->
	<xsl:variable name="fileindex" select="document('../fileindex.xml')/files"/>
	<xsl:variable name="filename" select="$fileindex/levels/level[@id=$id]"/>
	<xsl:variable name="level" select="document(concat('../levels/',$filename))/level"/>
	
	
	<xsl:variable name="amount_cells" select="count($level/map/row[1]/cell)"/>
	
	<div class="level">
		<!-- Remember what level it contains -->
		<xsl:attribute name="id">
			<xsl:value-of select="$level/level"/>
		</xsl:attribute>
		
		<xsl:if test="$level/@type = 1">
			<!-- Define size of container -->
			<xsl:attribute name="style">
				width:<xsl:value-of select='$amount_cells*10'/>px
			</xsl:attribute>
			
			<!-- "Load" the sprites -->
			<xsl:call-template name="level-sprites">
				<xsl:with-param name="id" select="$level/sprite_index"/>
			</xsl:call-template>
			
			<!-- Create a complete map -->
			<xsl:for-each select="$level/map/row">
				<xsl:sort select="position()" data-type="number" order="descending"/>
				<xsl:for-each select="cell">
					<div>
						<xsl:attribute name="class">
						<xsl:value-of select="concat('bg', $level/sprite_index ,'_', sprite)"/>
						<xsl:if test="solid = 'true'">
							<xsl:value-of select="' ShowSolid'"/>
						</xsl:if>
						<xsl:if test="event[normalize-space() or *]">
							<xsl:value-of select="concat(' event_', event)"/>
						</xsl:if>
						</xsl:attribute>
					</div>
				</xsl:for-each>
				
			</xsl:for-each>
			
			<!-- Show events -->
			
		
		</xsl:if>
		
	</div>
</xsl:template>


<xsl:template name="leveltype1">
		<h1>LEVEL!</h1>
		<!-- Create the levels -->
		<xsl:variable name="fileindex" select="document('../fileindex.xml')/files"/>
		<xsl:variable name="MainLevel" select="/level/level"/>
		<xsl:variable name="amount_cells" select="count(/level/map/row)"/>
		<div class="level-preview">
			<!-- Main level -->
			<xsl:call-template name="level">
				<xsl:with-param name="id" select="/level/level"/>
			</xsl:call-template>
			
			<div class="previews">
				<!-- Create Events overlay>
				<xsl:for-each select="/level/events/event">
					<div>
						<xsl:attribute name="id">event_<xsl:value-of select="position()-1"/>
						</xsl:attribute>
						<xsl:attribute name="class">EType_<xsl:value-of select="type"/></xsl:attribute>
						<xsl:attribute name="style">
							top: <xsl:value-of select="($amount_cells - position/y -1)*10 + 2"/>px;
							left: <xsl:value-of select="position/x*10 + 2"/>px;
						</xsl:attribute>
					</div>
				</xsl:for-each -->
				
				<!-- Create events information -->
				<xsl:for-each select="/level/events/event">
					<table>
						<xsl:attribute name="id">E_<xsl:value-of select="position()-1"/></xsl:attribute>
						
						<xsl:if test="type = 1">
							<tr><th class="title" colspan="6">Move event</th></tr>
							<tr>
								<th>ID</th>
								<th>Active</th>
								<th>level</th>
								<th>new x</th>
								<th>new y</th>
								<th>move</th>
							</tr>
							<tr>
								<td><xsl:value-of select="position()-1"/></td>
								<td><xsl:value-of select="active"/></td>
								<td><xsl:value-of select="data/d1"/></td>
								<td><xsl:value-of select="data/d2"/></td>
								<td><xsl:value-of select="data/d3"/></td>
								<td><xsl:value-of select="data/d4"/></td>
							</tr>
						</xsl:if>
						
						<xsl:if test="type = 2">
							<tr><th class="title" colspan="4">Show text box</th></tr>
							<tr>
								<th>ID</th>
								<th>Active</th>
								<th>Index ID</th>
								<th>String ID</th>
							</tr>
							<tr>
								<td><xsl:value-of select="position()-1"/></td>
								<td><xsl:value-of select="active"/></td>
								<td><xsl:value-of select="data/d1"/></td>
								<td><xsl:value-of select="data/d2"/></td>
							</tr>
							<tr><td colspan="4">TODO: insert string here</td></tr>
						</xsl:if>
					</table>
				</xsl:for-each>
				
				<!-- Create previews for all other levels -->
				<xsl:for-each select="$fileindex/levels/level">
					<xsl:if test="$MainLevel != @id">
						<xsl:call-template name="level">
							<xsl:with-param name="id" select="@id"/>
						</xsl:call-template>
					</xsl:if>
				</xsl:for-each>
				
				<!-- Link events overlay, event info and previews together -->
				<style>
					<xsl:for-each select="/level/events/event">
						#event_<xsl:value-of select="position()-1"/>:hover ~ #E_<xsl:value-of select="position()-1"/>{display:table}
						<xsl:if test="type = 1">
							#event_<xsl:value-of select="position()-1"/>:hover ~ [id="<xsl:value-of select="data/d1"/>"].level{display:block}
							#event_<xsl:value-of select="position()-1"/>:hover ~ [id="<xsl:value-of select="data/d1"/>"].level:before{
							display:block;
	<!-- Find the current level file -->
								<xsl:variable name="new_level" select="data/d1"/>
								<xsl:variable name="current_level" select="document(concat('../levels/', $fileindex/levels/level[@id=$new_level] ))/level"/>
								top: <xsl:value-of select="(count($current_level/map/row) - data/d3 -1)*10"/>px;
								left: <xsl:value-of select="data/d2*10"/>px;
							}
							
						</xsl:if>
					</xsl:for-each>
				</style>
			</div>
			
		</div>
		
		
		<!-- Stats -->
		<xsl:variable name="cells_x" select="count(/level/map/row[1]/cell)"/>
		<xsl:variable name="cells_y" select="count(/level/map/row)"/>
		<xsl:variable name="cells_total" select="count(/level/map/row/cell)"/>
		
		<xsl:variable name="events_total" select="count(/level/events/event)"/>
		
		
		<!-- Show stats about Main level -->
		<table style="clear:both">
			<tr><th class="title" colspan="2">Stats</th></tr>
			
			<!-- General stats -->
			<tr>
				<th colspan="2">General</th>
			</tr>
			<tr>
				<td>Type:</td>
				<td><xsl:value-of select="/level/@type"/></td>
			</tr>
			<tr>
				<td>Sprite Index:</td>
				<td><xsl:value-of select="/level/sprite_index"/></td>
			</tr>
			<tr>
				<td>Background:</td>
				<td><xsl:value-of select="/level/background_sprite"/></td>
			</tr>
			<tr>
				<td>Filesize:</td>
				<td><xsl:value-of select="5+$cells_total*2+$events_total*8+1"/> bytes</td>
			</tr>
			
			<!-- Stats about cells -->
			<tr>
				<th colspan="2">Cells</th>
			</tr>
			<xsl:if test="$cells_x*$cells_y != $cells_total">
				<tr><td class="warning" colspan="2">WARNING! Incorrect amount of cells!</td></tr>
			</xsl:if>
			<tr>
				<td>Amount:</td>
				<td><xsl:value-of select="$cells_total"/></td>
			</tr>
			<tr>
				<td>Width:</td>
				<td><xsl:value-of select="$cells_x"/></td>
			</tr>
			<tr>
				<td>Height:</td>
				<td><xsl:value-of select="$cells_y"/></td>
			</tr>
			<tr>
				<td>Size:</td>
				<td><xsl:value-of select="$cells_total*2"/> bytes</td>
			</tr>
			
			<!-- Stats about events -->
			<tr>
				<th colspan="2">Events</th>
			</tr>
			<tr>
				<td>Amount:</td>
				<td><xsl:value-of select="$events_total"/> event(s)</td>
			</tr>
			<tr>
				<td>Size:</td>
				<td><xsl:value-of select="$events_total*8"/> bytes</td>
			</tr>
			
		</table>
		
		
		<!-- Show events data -->
		<table>
			<tr><th class="title" colspan="6">Move events</th></tr>
			<tr>
				<th>ID</th>
				<th>Active</th>
				<th>Level</th>
				<th>x</th>
				<th>y</th>
				<th>move</th>
			</tr>
			<xsl:for-each select="/level/events/event">
				<xsl:if test="type = 1">
					<tr>
						<td><xsl:value-of select="position()-1"/></td>
						<td><xsl:value-of select="active"/></td>
						<td><xsl:value-of select="data/d1"/></td>
						<td><xsl:value-of select="data/d2"/></td>
						<td><xsl:value-of select="data/d3"/></td>
						<td><xsl:value-of select="data/d4"/></td>
					</tr>
				</xsl:if>
			</xsl:for-each>
		</table>
		<table>
			<tr><th class="title" colspan="5">Text box events</th></tr>
			<tr>
				<th>ID</th>
				<th>Active</th>
				<th>Index</th>
				<th>string ID</th>
				<th>move</th>
			</tr>
			<xsl:for-each select="/level/events/event">
				<xsl:if test="type = 2">
					<tr>
						<td><xsl:value-of select="position()-1"/></td>
						<td><xsl:value-of select="active"/></td>
						<td><xsl:value-of select="data/d1"/></td>
						<td><xsl:value-of select="data/d2"/></td>
						<td><xsl:value-of select="data/d3"/></td>
					</tr>
				</xsl:if>
			</xsl:for-each>
		</table>
		
		
		<!-- Create NXT file data -->
		<div class="code">
			<p class="init">
				b<xsl:value-of select="/level/@type"/>;
				b<xsl:value-of select="$cells_x"/>;
				b<xsl:value-of select="$cells_y"/>;
				b<xsl:value-of select="/level/sprite_index"/>;
				b<xsl:value-of select="/level/background_sprite"/>;
			</p>
			
			<!-- Cell data -->
			<xsl:for-each select="/level/map/row">
				<p class="row">
					<xsl:for-each select="cell">b<xsl:value-of select="sprite"/>;</xsl:for-each>
				</p>
			</xsl:for-each>
			<xsl:for-each select="/level/map/row">
				<p class="row">
					<xsl:for-each select="cell">
						%1;<xsl:call-template name="boolean">
							<xsl:with-param name="data" select="solid"/>
						</xsl:call-template>;<xsl:if test="event[normalize-space() or *]"><xsl:value-of select="event"/></xsl:if><xsl:if test="not(event[normalize-space() or *])"><xsl:value-of select="'127'"/></xsl:if>;
					</xsl:for-each>
				</p>
			</xsl:for-each>
			
			<!-- Event data -->
			<p class="init">b<xsl:value-of select="$events_total"/>;</p>
			<xsl:for-each select="/level/events/event">
				<p class="row">
					b<xsl:value-of select="action"/>;
					%1;<xsl:call-template name="boolean">
							<xsl:with-param name="data" select="active"/>
						</xsl:call-template>;<xsl:if test="next_event[normalize-space() or *]"><xsl:value-of select="next_event"/></xsl:if><xsl:if test="not(next_event[normalize-space() or *])"><xsl:value-of select="'127'"/></xsl:if>;
					%2;<xsl:call-template name="chance_type">
							<xsl:with-param name="data" select="chance/type"/>
						</xsl:call-template>;<xsl:value-of select="chance/chance"/>;
					
					<!-- Type specific -->
					<xsl:if test="action = 1">
						b<xsl:value-of select="data/d1"/>;
						b<xsl:value-of select="data/d2"/>;
						b<xsl:value-of select="data/d3"/>;
						b<xsl:call-template name="direction">
							<xsl:with-param name="data" select="data/d4"/>
						</xsl:call-template>;
					</xsl:if>
					<xsl:if test="action = 2">
						b<xsl:value-of select="data/d1"/>;
						b<xsl:value-of select="data/d2"/>;
						b<xsl:call-template name="direction">
							<xsl:with-param name="data" select="data/d3"/>
						</xsl:call-template>;
						b0;
					</xsl:if>
				</p>
			</xsl:for-each>
		</div>
</xsl:template>


<xsl:template name="leveltype2">
	<h1>Battle level</h1>
	<xsl:call-template name="other-sprites">
		<xsl:with-param name="type" select="'characters'"/>
	</xsl:call-template>
	<xsl:for-each select="/level/battle">
		<div class="battle">
			<p>Escape possible: <xsl:value-of select="escape"/></p>
			<xsl:for-each select="character">
				<div class="character">
					<div><xsl:attribute name="class">characters0_<xsl:value-of select='id'/></xsl:attribute></div>
					<p>ID: <xsl:value-of select="id"/></p>
					<p>Lvl: <xsl:value-of select="lvl"/></p>
				</div>
			</xsl:for-each>
		</div>
	</xsl:for-each>
	
	<div class="code">
		<p class="init">
			b<xsl:value-of select="/level/@type"/>;
			b<xsl:value-of select="count(/level/battle)"/>;
		</p>
		
		<xsl:for-each select="/level/battle">
			<p class="row">
				b<xsl:call-template name="boolean">
					<xsl:with-param name="data" select="escape"/>
				</xsl:call-template>;
				b<xsl:value-of select="count(character)"/>;
				<xsl:for-each select="character">
					b<xsl:value-of select="id"/>;
					b<xsl:value-of select="lvl"/>;
				</xsl:for-each>
			</p>
		</xsl:for-each>
	</div>
</xsl:template>

<!-- Create whole level preview -->
<xsl:template match="/">
<!--xsl:text disable-output-escaping="yes">
<![CDATA[<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">]]>
</xsl:text-->
<!--html xsl:version="1.0"
      xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
      xmlns="http://www.w3.org/TR/xhtml1/strict"-->
<html>
	<head>
		<link href="../shared/common.css" media="screen" rel="stylesheet" type="text/css"/>
	</head>
	
	<body>
		<xsl:choose>
			<xsl:when test="/level/@type = 1"><xsl:call-template name="leveltype1"/></xsl:when>
			<xsl:when test="/level/@type = 2"><xsl:call-template name="leveltype2"/></xsl:when>
			<xsl:otherwise><h1 class="warning">Error, unknown level type!</h1></xsl:otherwise>
		</xsl:choose>
		
	</body>
</html>
</xsl:template>


</xsl:stylesheet>